# Anurag Bishnoi, anurag.2357@gmail.com

# Run the following code to generate the lines and the automorphism group
# of the dual split Cayley hexagon H(4)^D

WriteListToFile := function(L, name)
# writes a list L to the file name
 local f, l, p;
 f := OutputTextFile(name, false);
 for l in L do
  for p in l do
    AppendTo(f, p , " ");
  od;
  AppendTo(f, "\n");
 od;
 CloseStream(f);
end;

WriteGroupToFile := function(G, name)
# writes the group G to the file name
 local f, g;
 f := OutputTextFile(name, false);
 PrintTo(f, String(G));
 CloseStream(f);
end;


get_lines := function(v, G, s, t)
 # returns the set of lines of the point-line geometry of order (s, t) 
 # that has [1..v] as the point set and G as its full automorphism group 
 # acting distance transitively on the points, and transitively on the lines 
 local points, orbs, dist1, perp, line, lines; 
 points := [1..v];
 orbs := Orbits(Stabilizer(G,1),points);; 
 dist1 := Filtered(orbs, x -> Size(x) = s*(t+1))[1];; # using distance transitivity
 perp := Union([1],dist1);;
 line := Intersection(perp,OnSets(perp,RepresentativeAction(G,1,dist1[1])));;
 lines := Orbit(G,line,OnSets);
 return lines;
end;

# H(4)^D
q := 4;
deg := (1+q)*(1 + q^2 + q^4); # number of points
order := 2*q^6*(q^6 - 1)*(q^2 - 1); # order of the full automorphism group
G := AllPrimitiveGroups(DegreeOperation,deg,Size,order)[2];;
lines := get_lines(deg, G, q, q);; 
WriteListToFile(lines, "lines");
WriteGroupToFile(G, "group"); 

